==> g77-0.5.14.tar.gz: g77-0.5.14/f/stu.h <==
/* stu.h -- Private #include File (module.h template V1.0)
   Copyright (C) 1995 Free Software Foundation, Inc.
   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).

This file is part of GNU Fortran.

GNU Fortran is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Fortran is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Fortran; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

   Owning Modules:
      stu.c

   Modifications:
*/

/* Allow multiple inclusion to work. */

#ifndef _H_f_stu
#define _H_f_stu

/* Simple definitions and enumerations. */


/* Typedefs. */


/* Include files needed by this one. */

#include "symbol.h"

/* Structure definitions. */


/* Global objects accessed by users of this module. */


/* Declare functions with prototypes. */

ffesymbol ffestu_sym_end_transition (ffesymbol s);
ffesymbol ffestu_sym_exec_transition (ffesymbol s);

/* Define macros. */

#define ffestu_init_0()
#define ffestu_init_1()
#define ffestu_init_2()
#define ffestu_init_3()
#define ffestu_init_4()
#define ffestu_terminate_0()
#define ffestu_terminate_1()
#define ffestu_terminate_2()
#define ffestu_terminate_3()
#define ffestu_terminate_4()

/* End of #include file. */

#endif

==> g77-0.5.18.tar.gz: g77-0.5.18/f/stu.h <==
/* stu.h -- Private #include File (module.h template V1.0)
   Copyright (C) 1995 Free Software Foundation, Inc.
   Contributed by James Craig Burley (burley@gnu.ai.mit.edu).

This file is part of GNU Fortran.

GNU Fortran is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Fortran is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Fortran; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA.

   Owning Modules:
      stu.c

   Modifications:
*/

/* Allow multiple inclusion to work. */

#ifndef _H_f_stu
#define _H_f_stu

/* Simple definitions and enumerations. */


/* Typedefs. */


/* Include files needed by this one. */

#include "symbol.h"

/* Structure definitions. */


/* Global objects accessed by users of this module. */


/* Declare functions with prototypes. */

ffesymbol ffestu_sym_end_transition (ffesymbol s);
ffesymbol ffestu_sym_exec_transition (ffesymbol s);

/* Define macros. */

#define ffestu_init_0()
#define ffestu_init_1()
#define ffestu_init_2()
#define ffestu_init_3()
#define ffestu_init_4()
#define ffestu_terminate_0()
#define ffestu_terminate_1()
#define ffestu_terminate_2()
#define ffestu_terminate_3()
#define ffestu_terminate_4()

/* End of #include file. */

#endif
